@@ -18,8 +18,7 @@ __docformat__ = "reStructuredText"
 
 import os
 import unittest
-
-from zope.testing import doctest
+import doctest
 
 import pytz
 
